# Full edifice coverage data 

# Data from Cuvelier et al. 2011: mussel and microbial mats total coverage by year over the 4 sides. 
# n = 8 time points (+ 2 soon for 2018 & 2020)
# unit = % 

# variables: mean and standard deviation of the 4 sides based on coverage of the full edifice = Cover_percentages_10treshold_last_years

setwd(getwd()) # set working directory
rm(list = ls()) # clean workspace
graphics.off() # clean graphics
gc() # remove temporary files

Sys.setenv(TZ = "UTC") # set time zone 
Sys.timezone()

# Libraries ----
library(ncdf4)
library(bspec)
library(raster)
library(chron)
library(lattice)
library(RColorBrewer)
library(tidyverse)
library(lubridate)
library(dygraphs)
library(xts)
library(tmap)
library(ggplot2)
library(tsbox)
library(sp)
library(ggpubr)
library(adespatial)
library(fields)
library(boot)
library(pastecs)
library(car)
library(lmtest)
library(stats)
library(RcppRoll)
library(nlme)
library(astsa)
library(forecast)
library(aTSA)
library(sandwich)
library(e1071)
library(jtools)
library(paletteer)
library(readxl)
library(stringr)
library(imputeTS)
library(vegan)

#__________________________________________________________________________________________________

# Load full coverage of the 4 sides of the edifice ----
Cover_percentages <- read_excel("Cover_percentages_10treshold_last_years.xlsx")
colnames(Cover_percentages) <- c("Side", "Year", "A1", "A2a", "A2b", "A3", "A4a", "A4b", "ASub1a", "ASub1b", "ASub2", "unique", "total_pixel", "undetermined")

# remove sides where the incertitude is too high: based on assemblages annotation images 
# ES 1998, NP 2005 not the full edifice  
# SP 2005 left and right we do the sum from the number of pixel (file = cover_percentage_10_thershold.xlsx)

Cover_percentages <- Cover_percentages[-c(2, 11, 44, 45),]

# arrange 
Cover_percentages <- Cover_percentages[order(Cover_percentages$Year, decreasing = FALSE),]
Cover_percentages <- Cover_percentages[order(Cover_percentages$Side, decreasing = FALSE),]

years.f <- as.factor(Cover_percentages$Year)
side.f <- as.factor(Cover_percentages$Side)

# Compute mean and standard deviation of microbial mats and mussels ----
mats_1 <- as.data.frame(array(data = NA,
                              dim = c(10,3)))
colnames(mats_1) <- c('mean', 'sd', 'time')
mats_1$time <- as.numeric(levels(years.f))


mussels_1 <- as.data.frame(array(data = NA,
                              dim = c(10,3)))
colnames(mussels_1) <- c('mean', 'sd', 'time')
mussels_1$time <- as.numeric(levels(years.f))

for (i in 1:length(levels(years.f))) {
  
  fauna_y <- filter(Cover_percentages, Year == levels(years.f)[i])
  sum_microbial <- rowSums(fauna_y[,c(5,8,10)], na.rm = TRUE) # microbial mats
  mm_mean <- mean(sum_microbial)
  mm_sd <- sd(sum_microbial)
  mats_1[i,1] <- mm_mean
  mats_1[i,2] <- mm_sd
  
  sum_mussels <- rowSums(fauna_y[,c(3,4,5)], na.rm = TRUE)
  m_mean <- mean(sum_mussels)
  m_sd <- sd(sum_mussels)
  mussels_1[i,1] <- m_mean
  mussels_1[i,2] <- m_sd
  
}

mats <- mats_1
mussels <- mussels_1
mats$time <- as.numeric(mats$time)

# Plots ----

plot(x = mats$time,
     y = mats$mean,
     pch = 0,
     type = "o",
     ylim = c(0, 80),
     main = "Microbial mat % coverage",
     xlab = "Time",
     ylab = "% coverage")

arrows(x0 = mats$time,
       y0 = (mats$mean - mats$sd),
       x1 = mats$time,
       y1 = (mats$mean + mats$sd),
       length = 0.05,
       angle = 90,
       code = 3)

plot(x = mussels$time,
     y = mussels$mean,
     type = "o",
     ylim = c(0, 80),
     main = "Mussel % coverage",
     xlab = "Time",
     ylab = "% coverage")

arrows(x0 = mussels$time,
       y0 = (mussels$mean - mussels$sd),
       x1 = mussels$time,
       y1 = (mussels$mean + mussels$sd),
       length = 0.05,
       angle = 90,
       code = 3)

# Spearman correlation test = trend ----
print("microbial mats")
cor.test(y = mats$mean, 
         x = mats$time, 
         method = "spearman")

print("mussels")
cor.test(y = mussels$mean, 
         x = mussels$time, 
         method = "spearman")

print("mussel vs mats")
cor.test(x = mats$mean, 
         y = mussels$mean, 
         method = "spearman")


# URT ----

library(rpart)
library(rpart.plot)


## Mats ----
out.tree <- rpart(mats$mean ~ mats$time, 
                  method = "anova", 
                  control = rpart.control(minbucket = 2, cp = 0))
plotcp(out.tree)
printcp(out.tree)
summary(out.tree)

# choose the number of groups
out.tree.final <- prune(out.tree, cp = 0.19)
rpart.plot(out.tree.final)
printcp(out.tree.final)
# Root node error is the percent of correctly sorted records at the first (root) splitting node.
summary(out.tree.final)

splits_tree <- out.tree.final$splits

summary(out.tree.final)

floor(splits_tree[,4])

# plot
pdf(file = "plot_full_edifice_coverage_breaks_mats.pdf",
    width = 8,
    height = 6)
plot(x = mats$time, 
     y = mats$mean, 
     type = "o", 
     ylim = c(0, 80), 
     main = "Microbial mats % coverage", 
     xlab = "Time", 
     ylab = "% coverage",
     pch = 15)

arrows(x0 = mats$time, 
       y0 = (mats$mean-mats$sd), 
       x1 = mats$time, 
       y1 = (mats$mean+mats$sd), 
       length = 0.05, 
       angle = 90, 
       code = 3)

abline(v = floor(splits_tree[,4]), 
       lty = 2, 
       col = "blue", 
       lwd = 2)
text(x = floor(splits_tree[,4]),
     y = 8, 
     labels = c("2016","1999"), 
     col = "red", 
     pos = 2, 
     srt = 90)
dev.off()

## Mussels ----

out.tree <- rpart(mussels$mean ~ mussels$time, 
                  method = "anova", 
                  control = rpart.control(minbucket = 2, cp = 0))
plotcp(out.tree)
printcp(out.tree)
summary(out.tree)


out.tree.final <- prune(out.tree, cp = 0.22)
rpart.plot(out.tree.final)
printcp(out.tree.final)
summary(out.tree.final)

splits_tree <- out.tree.final$splits

floor(splits_tree[,4]) # 2011

# Plot 
pdf(file = "plot_full_edifice_coverage_breaks_mussels.pdf",
    width = 8,
    height = 6)
plot(x = mussels$time, 
     y = mussels$mean, 
     type = "o", 
     ylim = c(0, 80), 
     main = "Mussel % coverage", 
     xlab = "Time", 
     ylab = "% coverage",
     pch = 16)

arrows(x0 = mussels$time, 
       y0 = (mussels$mean - mussels$sd), 
       x1 = mussels$time, 
       y1 = (mussels$mean + mussels$sd), 
       length = 0.05, 
       angle = 90, 
       code = 3)

abline(v = floor(splits_tree[,4]), 
       lty = 2, 
       col = "blue", 
       lwd = 2)
text(x = floor(splits_tree[,4]),
     y = 8, 
     labels = c("2011"), 
     col = "red", 
     pos = 2, 
     srt = 90)
dev.off()



# Segmented regression ----
# just to compare results 
library(segmented)

## Mussels ----
summary(res.lm.mussels <- lm(mean ~ time, 
                             data = mussels, 
                             na.action = "na.omit"))

par(mfrow = c(2, 2))
plot(res.lm.mussels)

summary(res.seg.mussels <- segmented(res.lm.mussels, 
                                     seg.Z =~ time, 
                                     npsi = 1))

slope(res.seg.mussels)
res.seg.mussels$psi  # btw 2005 and 2006

## Mats ----
summary(res.lm.mats <- lm(mean ~ time, 
                          data = mats, 
                          na.action = "na.omit"))

par(mfrow = c(2, 2))
plot(res.lm.mats)

summary(res.seg.mats <- segmented(res.lm.mats, 
                                  seg.Z =~ time, 
                                  npsi = 2))

slope(res.seg.mats)
res.seg.mats$psi  # 2002 and 2008
